# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-01-14 16:15
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_project', '0006_auto_20200114_1547'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='owned_customers', to=settings.AUTH_USER_MODEL),
        ),
    ]
